#!/bin/sh

proc_unix()
{
      echo "Configuring AllegroGL to build on Unix..."
}

proc_fix()
{
      echo "Configuring AllegroGL for $1..."
      echo "# generated by fix.sh" > makefile
      echo "include make/$2" >> makefile
}

proc_fix_osx_ub()
{
	echo "Configuring AllegroGL for Mac OSX Universal Binary ..."

	echo "# generated by fix.sh"      > makefile
	echo "UB = 1"                    >> makefile
	echo "include make/makefile.osx" >> makefile
}

display_help()
{
      echo "Compilation target adjustment."
      echo "  Usage: fix <platform> [--dtou|--utod|--quick]"
      echo ""
      echo "  <platform> is one of: djgpp, mingw32, unix, macosx,"
	  echo "  macosx-universal, beos, haiku"
      echo ""
      echo "  --dtou converts from DOS/Win32 format to Unix"
      echo "  --utod converts from Unix format to DOS/Win32"
      echo "  --quick does no line ending conversion"
      echo "  If no parameter is specified --quick is assumed"
      echo ""
      echo "  Example: fix unix --dtou"
      echo ""
}

proc_filelist()
{
	AL_FILELIST=`find . -type f '!' -path "*.svn*" -a "(" \
		-name "*.c" -o -name "*.cfg" -o -name "*.cpp" -o -name "*.dep" -o \
		-name "*.h" -o -name "*.hin" -o -name "*.in" -o -name "*.inc" -o \
		-name "*.m4" -o -name "*.mft" -o -name "*.s" -o \
		-name "*.spec" -o -name "*.pl" -o -name "*.txt" -o -name "*._tx" -o \
		-name "makefile.*" -o -name "readme.*" -o -name "changelog" \
		")"`

	# touch unix shell scripts?
	if [ "$1" != "omit_sh" ]; then
		AL_FILELIST="$AL_FILELIST `find . -type f -name '*.sh' \
		    -o -name configure`"
	fi

	# touch DOS batch files?
	if [ "$1" != "omit_bat" ]; then
		AL_FILELIST="$AL_FILELIST `find . -type f -name '*.bat'`"
	fi
}

proc_dtou()
{
	echo "Converting files from DOS/Win32 to Unix ..."
	proc_filelist "omit_bat"
	/bin/sh ../../misc/dtou.sh $AL_FILELIST
}

proc_utod()
{
	echo "Converting files from Unix to DOS/Win32 ..."
	proc_filelist "omit_sh"
	/bin/sh ../../misc/utod.sh $AL_FILELIST
}

if [ -z "$1" ]; then
	display_help
	exit 0
fi

case "$1" in
	djgpp	) proc_fix "DJGPP" "makefile.dj";;
	haiku	) proc_fix "Haiku" "makefile.gen";;
	mingw	) proc_fix "Mingw32" "makefile.mgw";;
	mingw32	) proc_fix "Mingw32" "makefile.mgw";;
	# used only by allegro's zipup.sh in packaging process
	msvc	) proc_fix "MSVC" "makefile.vc";;
	unix	) proc_unix;;
	macosx-universal ) proc_fix_osx_ub ;;
	macosx  ) proc_fix "MacOS X" "makefile.osx";;
	*	) echo "Platform not supported by AllegroGL."; exit 0;;
esac

case "$2" in
	--utod	) proc_utod;;
	--dtou	) proc_dtou;;
esac

# set execute permissions just in case.

chmod +x *.sh misc/*.sh projects/msvc2005/*.sh projects/msvc6/*.sh
if [ -f configure ]; then
	chmod +x configure
fi
