#!/bin/sh
#
# Sets up the logg package for building with the specified compiler.
#

proc_help()
{
   echo
   echo "Usage: $0 <platform> [--quick|--dtou|--utod]"
   echo
   echo "Where platform is one of: mingw32, unix, macosx, macosx-universal,"
   echo "  beos, haiku"
   echo "The --quick parameter turns off text file conversion, --dtou converts from"
   echo "DOS/Win32 format to Unix, --utod converts from Unix to DOS/Win32 format."
   echo "If no parameter is specified --quick is assumed."
   echo

   AL_NOCONV="1"
}

proc_fix()
{
   echo "Configuring logg for $1 ..."

   echo "# generated by fix.sh" > Makefile
   echo "include $2"           >> Makefile
}

proc_fix_osx_ub()
{
   echo "Configuring logg for Mac OSX Universal Binary ..."

   echo "# generated by fix.sh"      > Makefile
   echo "UB = 1"                    >> Makefile
   echo "include Makefile.osx"      >> Makefile
}

proc_filelist()
{
   # common files.
   AL_FILELIST=`find . -type f "(" ! -path "*/.*" ")" -a "(" \
      -name "*.c" -o -name "*.cfg" -o -name "*.cpp" -o -name "*.def" -o \
      -name "*.h" -o -name "*.hin" -o -name "*.in" -o -name "*.inc" -o \
      -name "*.m" -o -name "*.m4" -o -name "*.mft" -o -name "*.s" -o \
      -name "*.rc" -o -name "*.rh" -o -name "*.spec" -o -name "*.pl" -o \
      -name "*.txt" -o -name "*._tx" -o -name "Makefile*" -o \
      -name "*.inl" -o -name "configure" -o -name "CHANGES" -o \
      -name "AUTHORS" -o -name "THANKS" ")" \
   `

   # touch unix shell scripts?
   if [ "$1" != "omit_sh" ]; then
      AL_FILELIST="$AL_FILELIST `find . -type f -name '*.sh'`"
   fi

   # touch DOS batch files?
   if [ "$1" != "omit_bat" ]; then
      AL_FILELIST="$AL_FILELIST `find . -type f -name '*.bat'`"
   fi
}

proc_utod()
{
   echo "Converting files from Unix to DOS/Win32 ..."
   proc_filelist "omit_sh"
   sh ../../misc/utod.sh $AL_FILELIST
}

proc_dtou()
{
   echo "Converting files from DOS/Win32 to Unix ..."
   proc_filelist "omit_bat"
   sh ../../misc/dtou.sh $AL_FILELIST
}

# prepare loadpng for the given platform.

if [ -z "$1" ]; then
   proc_help
   exit 0
fi

case "$1" in
   "beos"    ) proc_fix "BeOS"              "Makefile.be";;
   "haiku"   ) proc_fix "Haiku"             "Makefile.be";;
   "mingw"   ) proc_fix "Windows (MinGW)"   "Makefile.mingw";;
   "mingw32" ) proc_fix "Windows (MinGW)"   "Makefile.mingw";;
   "unix"    ) proc_fix "Unix"              "Makefile.unix";;
   "macosx"  ) proc_fix "Mac OS X"          "Makefile.osx";;
   "macosx-universal" ) proc_fix_osx_ub ;;
   # used only by allegro's zipup.sh in packaging process
   "msvc"    ) proc_fix "Windows (MSVC)"    "Makefile.msvc";;
   "help"    ) proc_help;;
   *         ) echo "Platform not supported by logg." ;;
esac

# convert all text-file line endings.

if [ "$AL_NOCONV" != "1" ]; then
   case "$2" in
      "--utod"  ) proc_utod "$1";;
      "--dtou"  ) proc_dtou "$1";;
   esac
fi

# set execute permissions just in case.

chmod +x *.sh
